@@ -16,14 +16,24 @@ class TestClass(qrunner.TestCase):
 
     def start(self):
         self.hp = HomePage(self.driver)
+        self.elem_close = self.elem(label='close white big', desc='首页广告关闭按钮')
+        self.elem_my = self.elem(label='我的', desc='首页底部我的入口')
 
-    @title('从首页进入我的页')
-    def testcase(self):
+    @title('pom模式用例')
+    def test_pom(self):
         self.start_app()
         self.hp.go_my()
         self.assertText('我的订单')
         self.stop_app()
 
+    @title('普通模式用例')
+    def test_normal(self):
+        self.start_app()
+        self.elem_close.click()
+        self.elem_my.click()
+        self.assertText('我的订单')
+        self.stop_app()
+
 
 if __name__ == '__main__':
     qrunner.main(
