@@ -2,9 +2,10 @@ import inspect
 from typing import Union
 from wda import Selector
 from qrunner.utils.log import logger
-from qrunner.utils.config import conf
+from qrunner.utils.config import config
 from qrunner.core.ios.driver import IosDriver
-from qrunner.utils.exceptions import NoSuchElementException, ElementNameEmptyException
+from qrunner.utils.exceptions import NoSuchElementException, \
+    ElementNameEmptyException
 
 
 class IosElement(object):
@@ -12,6 +13,7 @@ class IosElement(object):
     IOS原生元素定义
     """
     def __init__(self,
+                 driver=None,
                  name=None,
                  label=None,
                  value=None,
@@ -48,30 +50,20 @@ class IosElement(object):
         if self.desc is None:
             raise ElementNameEmptyException('请设置控件名称')
         self._kwargs = kwargs
+        self._driver = None
 
-        # 驱动初始化
-        _serial_no = conf.get_item('ios', 'serial_no')
-        self._driver = IosDriver.get_instance(_serial_no)
-        self._d = self._driver.d
+        # # 驱动初始化
+        # _serial_no = config.get_item('ios', 'serial_no')
+        # self._driver = IosDriver.get_instance(_serial_no)
+        # self._d = self._driver.d
 
-    # 多线程处理异常弹窗
-    def handle_alert(self, alert_list):
-        """
-        根据不同定位方式进行点击
-        @return:
-        """
-        def click_alert(loc):
-            if '//' in loc:
-                element = self._d.xpath(loc)
-            else:
-                element = self._d(label=loc)
-            element.click_exists()
-
-        # 多线程存在问题，目前没有使用多线程
-        if alert_list:
-            print(f'处理弹窗: {alert_list}')
-            for alert in alert_list:
-                click_alert(alert)
+    def get_driver(self):
+        if self._driver is not None :
+            driver = self._driver
+        else:
+            serial_no = config.get_device()
+            driver = IosDriver.get_instance(serial_no)
+        return driver
 
     # def _find_element(self, retry=3, timeout=3):
     #     """
@@ -102,22 +94,46 @@ class IosElement(object):
         @param timeout: 单次查找超时时间
         @return:
         """
-        element = self._d.xpath(self._xpath) if \
-            self._xpath else self._d(**self._kwargs)[self._index]
-        self.handle_alert(alert_list)
+
+        # 多线程处理异常弹窗
+        def handle_alert(driver, alert_list):
+            """
+            根据不同定位方式进行点击
+            @return:
+            """
+
+            def click_alert(loc):
+                if '//' in loc:
+                    element = driver.d.xpath(loc)
+                else:
+                    element = driver.d(label=loc)
+                element.click_exists()
+
+            # 多线程存在问题，目前没有使用多线程
+            if alert_list:
+                print(f'处理弹窗: {alert_list}')
+                for alert in alert_list:
+                    click_alert(alert)
+
+        # 驱动初始化
+        driver = self.get_driver()
+
+        element = driver.d.xpath(self._xpath) if \
+            self._xpath else driver.d(**self._kwargs)[self._index]
+        handle_alert(driver, alert_list)
         cur_retry = retry
         while not element.wait(timeout=timeout):
             if cur_retry > 0:
                 logger.warning(f'第{retry-cur_retry+1}次重试，查找元素： {self._kwargs},{self._index}')
                 cur_retry -= 1
-                self.handle_alert(alert_list)
+                handle_alert(driver, alert_list)
             else:
                 frame = inspect.currentframe().f_back
                 caller = inspect.getframeinfo(frame)
                 logger.warning(f'【{caller.function}:{caller.lineno}】未找到元素 {self._kwargs}')
                 return None
-        elements = self._d.xpath(self._xpath).find_elements() if \
-            self._xpath else self._d(**self._kwargs)
+        elements = driver.d.xpath(self._xpath).find_elements() if \
+            self._xpath else driver.d(**self._kwargs)
         return elements
 
     def get_elements(self, retry=3, timeout=3, alert_list=None):
@@ -128,12 +144,14 @@ class IosElement(object):
         @param alert_list
         @return:
         """
+        driver = self.get_driver()
+
         elements: Union[Selector] = self._find_element(retry=retry, timeout=timeout, alert_list=alert_list)
         if elements is None:
-            self._driver.screenshot(f'[控件 {self.desc}] 定位失败')
+            driver.screenshot(f'[控件 {self.desc}] 定位失败')
             raise NoSuchElementException(f'[控件 {self.desc}] 定位失败')
         else:
-            self._driver.screenshot(self.desc)
+            driver.screenshot(self.desc)
         return elements
 
     # def __getitem__(self, index):
@@ -215,7 +233,7 @@ class IosElement(object):
     def rect(self):
         """获取元素左上角坐标和宽高"""
         logger.info(f'获取元素: {self._kwargs} 的左上角坐标和宽高')
-        return [item * self._d.scale for item in list(self.get_element().bounds)]
+        return [item * self.get_driver().d.scale for item in list(self.get_element().bounds)]
 
     def exists(self, timeout=1):
         """
