@@ -10,6 +10,8 @@ from qrunner.utils.allure_data import get_allure_data
 
 # 钉钉机器人
 class DingTalk:
+    """消息格式参考：https://open.dingtalk.com/document/robots/custom-robot-access"""
+
     def __init__(self, secret=None, url=None):
         self.secret = secret
         self.url = url
@@ -26,6 +28,11 @@ class DingTalk:
 
     # 发送钉钉机器人通知
     def send_msg(self, msg_data):
+        """
+        参考：https://open.dingtalk.com/document/robots/custom-robot-access
+        @param msg_data:
+        @return:
+        """
         # 从gen_timestamp_and_sign方法获取timestamp和sign
         timestamp, sign = self.__gen_timestamp_and_sign()
         # 机器人url
